==> haskell-hspec-core-2.4.3-4-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hspec-core.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hspec-core
version: 2.4.3
id: hspec-core-2.4.3-351sCVxQ82zEBnxphJv1Br
key: hspec-core-2.4.3-351sCVxQ82zEBnxphJv1Br
license: MIT
copyright: (c) 2011-2017 Simon Hengel,
           (c) 2011-2012 Trystan Spangler,
           (c) 2011 Greg Weber
maintainer: Simon Hengel <sol@typeful.net>
stability: experimental
homepage: http://hspec.github.io/
synopsis: A Testing Framework for Haskell
description:
    This package exposes internal types and functions that can be used to extend Hspec'\''s functionality.
category: Testing
exposed: True
exposed-modules:
    Test.Hspec.Core.Spec Test.Hspec.Core.Hooks Test.Hspec.Core.Runner
    Test.Hspec.Core.Formatters Test.Hspec.Core.QuickCheck
    Test.Hspec.Core.Util
hidden-modules: Test.Hspec.Core.Compat Test.Hspec.Core.Config
                Test.Hspec.Core.Example Test.Hspec.Core.FailureReport
                Test.Hspec.Core.Formatters.Diff Test.Hspec.Core.Formatters.Free
                Test.Hspec.Core.Formatters.Internal
                Test.Hspec.Core.Formatters.Monad Test.Hspec.Core.Options
                Test.Hspec.Core.QuickCheckUtil Test.Hspec.Core.Runner.Eval
                Test.Hspec.Core.Spec.Monad Test.Hspec.Core.Timer
                Test.Hspec.Core.Tree Data.Algorithm.Diff Paths_hspec_core
abi: 2e62ca7c5bed49fa017160a5ba9f5462
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/hspec-core-2.4.3
library-dirs: /usr/lib/ghc-8.0.1/site-local/hspec-core-2.4.3
data-dir: /usr/share/arm-linux-ghc-8.0.1/hspec-core-2.4.3
hs-libraries: HShspec-core-2.4.3-351sCVxQ82zEBnxphJv1Br
depends:
    HUnit-1.6.0.0-FzD79SWxsfL7BH2Ung8YXe
    QuickCheck-2.9.2-3a8nWdLsV8cEn9LdMoftRm
    ansi-terminal-0.6.3-EZA1Pyq8DBj2Viel0l4pEB array-0.5.1.1
    async-2.1.1.1-H3AbYkdNxWLAjCWaC7fyS4 base-4.9.0.0
    call-stack-0.1.0-izRGIczcaH64KMRs1Wg8q deepseq-1.4.2.0
    directory-1.2.6.2 filepath-1.4.1.0
    hspec-expectations-0.8.2-LiEkzoyhl0hJjydPrYgxwd
    quickcheck-io-0.1.4-3h8K9L34wDvGTXUJ3fY9nE
    random-1.1-54KmMHXjttlERYcr1mvsAe
    setenv-0.1.1.3-5zeeXxY3qb3AsPnIgczcsm
    tf-random-0.5-HnlpEtrVBp6BTiXtvzYbx6 time-1.6.0.1
    transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-hspec-core/html/hspec-core.haddock
haddock-html: /usr/share/doc/haskell-hspec-core/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-core-2.4.3-5-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hspec-core.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hspec-core
version: 2.4.3
id: hspec-core-2.4.3-9QEWWqcuOQ477wajab1a2t
key: hspec-core-2.4.3-9QEWWqcuOQ477wajab1a2t
license: MIT
copyright: (c) 2011-2017 Simon Hengel,
           (c) 2011-2012 Trystan Spangler,
           (c) 2011 Greg Weber
maintainer: Simon Hengel <sol@typeful.net>
stability: experimental
homepage: http://hspec.github.io/
synopsis: A Testing Framework for Haskell
description:
    This package exposes internal types and functions that can be used to extend Hspec'\''s functionality.
category: Testing
exposed: True
exposed-modules:
    Test.Hspec.Core.Spec Test.Hspec.Core.Hooks Test.Hspec.Core.Runner
    Test.Hspec.Core.Formatters Test.Hspec.Core.QuickCheck
    Test.Hspec.Core.Util
hidden-modules: Test.Hspec.Core.Compat Test.Hspec.Core.Config
                Test.Hspec.Core.Example Test.Hspec.Core.FailureReport
                Test.Hspec.Core.Formatters.Diff Test.Hspec.Core.Formatters.Free
                Test.Hspec.Core.Formatters.Internal
                Test.Hspec.Core.Formatters.Monad Test.Hspec.Core.Options
                Test.Hspec.Core.QuickCheckUtil Test.Hspec.Core.Runner.Eval
                Test.Hspec.Core.Spec.Monad Test.Hspec.Core.Timer
                Test.Hspec.Core.Tree Data.Algorithm.Diff Paths_hspec_core
abi: 882914d7086a2d571d9c949e67aedfc3
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/hspec-core-2.4.3
library-dirs: /usr/lib/ghc-8.0.1/site-local/hspec-core-2.4.3
data-dir: /usr/share/arm-linux-ghc-8.0.1/hspec-core-2.4.3
hs-libraries: HShspec-core-2.4.3-9QEWWqcuOQ477wajab1a2t
depends:
    HUnit-1.6.0.0-FzD79SWxsfL7BH2Ung8YXe
    QuickCheck-2.9.2-3a8nWdLsV8cEn9LdMoftRm
    ansi-terminal-0.6.3.1-C5gpy392zkR1qCeRuDySE4 array-0.5.1.1
    async-2.1.1.1-H3AbYkdNxWLAjCWaC7fyS4 base-4.9.0.0
    call-stack-0.1.0-izRGIczcaH64KMRs1Wg8q deepseq-1.4.2.0
    directory-1.2.6.2 filepath-1.4.1.0
    hspec-expectations-0.8.2-LiEkzoyhl0hJjydPrYgxwd
    quickcheck-io-0.1.4-3h8K9L34wDvGTXUJ3fY9nE
    random-1.1-54KmMHXjttlERYcr1mvsAe
    setenv-0.1.1.3-5zeeXxY3qb3AsPnIgczcsm
    tf-random-0.5-HnlpEtrVBp6BTiXtvzYbx6 time-1.6.0.1
    transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-hspec-core/html/hspec-core.haddock
haddock-html: /usr/share/doc/haskell-hspec-core/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
